import { _decorator, Component, Node, RichText, Socket } from 'cc';
import io from './plugins/socket.io.js';

const { ccclass, property } = _decorator;
 
@ccclass('SocketConnector')
export class SocketConnector extends Component {

    @property(RichText)
    consoleText: RichText = null!;

    private _socket:any = null;

    start () {
        this._socket = io('wss://dmr-socketio.herokuapp.com/', {
            transports: ['websocket', 'polling'],
            reconnection: true,
            forceNew : true,

            reconnectionAttempts : 10,
            reconnectionDelay : 500,
            randomizationFactor : 0,
            rememberUpgrade : true,
            timestampRequests : true
        });
        this._handleConnectionStatus(this._socket);
    }

    _handleConnectionStatus(socket: any) {

        socket.on("time", (data) => {
            console.log("SockerManager - time: " + data);
            this.consoleText.string = "SockerManager - time: " + data;
        });

        socket.on("connect", () => {
            console.log("SockerManager - health-check CONNECTED!");
            this.consoleText.string = "SockerManager - health-check CONNECTED!";
        });

        socket.on("disconnect", () => {
            console.log("SocketManager - DISCONNECTED.");
            this.consoleText.string = "SocketManager - DISCONNECTED.";
        });

        socket.on('reconnecting', (attempt: any) => {
            console.log("reconnecting" + attempt);
            this.consoleText.string = 'reconnecting' + attempt;
        });

        socket.on('reconnect_error', (error: any) => { // eslint-disable-line
            console.log("SockerManager - reconnect_error " + error);
            this.consoleText.string = `SockerManager - reconnect_error ${error}`;
        });

        socket.on('force-disconnect', (message: any) => { // eslint-disable-line
            console.log("SocketManager - force-disconnect >>> close connect!" + message);
            this.consoleText.string = "SocketManager - force-disconnect >>> close connect! "  + message;
        });

        socket.on('ping', () => {
            this.consoleText.string = "ping";
        });
        socket.on('pong', (latency: any) => {
            this.consoleText.string = 'pong';
        });
    }
}

